@@ -2,6 +2,7 @@ import when from 'when';
 
 import IronicApiService from '../../js/services/IronicApiService';
 import MistralApiService from '../../js/services/MistralApiService';
+import { mockGetIntl } from './utils';
 import NodesActions from '../../js/actions/NodesActions';
 import NotificationActions from '../../js/actions/NotificationActions';
 import NodesConstants from '../../js/constants/NodesConstants';
@@ -106,14 +107,16 @@ describe('Asynchronous Nodes Actions', () => {
     spyOn(utils, 'getServiceUrl').and.returnValue('mock-url');
     spyOn(NodesActions, 'requestNodes');
     spyOn(NodesActions, 'receiveNodes');
-    spyOn(NodesActions, 'fetchNodesMACs');
     // Mock the service call.
     spyOn(IronicApiService, 'getNodes').and.callFake(
-      createResolvingPromise({ nodes: [{ uuid: 0 }] })
+      createResolvingPromise({ nodes: [{ uuid: '123' }] })
     );
-    // Note that `getNode` is called multilpe times but always returns the same response
+    // Note that `getNode` is called multiple times but always returns the same response
     // to keep the test simple.
-    spyOn(IronicApiService, 'getNode').and.callFake(createResolvingPromise({ uuid: 0 }));
+    spyOn(IronicApiService, 'getNode').and.callFake(createResolvingPromise({ uuid: 'uuid' }));
+    spyOn(IronicApiService, 'getNodePorts').and.callFake(createResolvingPromise({
+      ports: [{ uuid: 'port1', address: 'mac' }]}));
+
     // Call the action creator and the resulting action.
     // In this case, dispatch and getState are just empty placeHolders.
     NodesActions.fetchNodes()(() => {}, () => {});
@@ -126,12 +129,22 @@ describe('Asynchronous Nodes Actions', () => {
   });
 
   it('dispatches receiveNodes', () => {
-    expect(NodesActions.receiveNodes).toHaveBeenCalledWith({ 0:{ uuid: 0 }});
+    expect(NodesActions.receiveNodes).toHaveBeenCalledWith({
+      nodes: {
+        123: {
+          uuid: '123',
+          portsDetail: ['port1']
+        }
+      },
+      ports: {
+        port1: {
+          uuid: 'port1',
+          address: 'mac'
+        }
+      }
+    });
   });
 
-  it('dispatches fetchNodesMACs', () => {
-    expect(NodesActions.fetchNodesMACs).toHaveBeenCalledWith({ 0:{ uuid: 0 }});
-  });
 });
 
 describe('Asynchronous Introspect Nodes Action', () => {
@@ -169,6 +182,11 @@ describe('nodesIntrospectionFinished', () => {
 
   it('handles successful nodes introspection', () => {
     const messagePayload = {
+      execution: {
+        input: {
+          node_uuids: ['598612eb-f21b-435e-a868-7bb74e576cc2']
+        }
+      },
       status: 'SUCCESS',
       message: 'Nodes Introspection was successful',
       introspected_nodes: {
@@ -179,7 +197,7 @@ describe('nodesIntrospectionFinished', () => {
       ttl: 3600
     };
 
-    NodesActions.nodesIntrospectionFinished(messagePayload)(() => {}, () => {});
+    NodesActions.nodesIntrospectionFinished(messagePayload)(() => {}, () => {}, mockGetIntl);
 
     expect(NodesActions.fetchNodes).toHaveBeenCalled();
     expect(NotificationActions.notify).toHaveBeenCalled();
@@ -187,26 +205,27 @@ describe('nodesIntrospectionFinished', () => {
 
   it('handles failed nodes introspection', () => {
     const messagePayload = {
-      status: 'FAILED',
-      message: 'Nodes Introspection failed',
-      introspected_nodes: {
-        '598612eb-f21b-435e-a868-7bb74e576cc2': {
-          finished: true, error: 'Some error occurred on this node'
+      execution: {
+        input: {
+          node_uuids: ['598612eb-f21b-435e-a868-7bb74e576cc2']
         }
       },
+      status: 'FAILED',
+      message: ['Nodes Introspection failed', 'Some error occurred during introspection'],
+      introspected_nodes: {},
       execution_id: '622eb415-a522-4016-b5f6-6e9e0b3f687a',
       queue_name: 'tripleo',
       ttl: 3600
     };
 
-    NodesActions.nodesIntrospectionFinished(messagePayload)(() => {}, () => {});
+    NodesActions.nodesIntrospectionFinished(messagePayload)(() => {}, () => {}, mockGetIntl);
 
     expect(NodesActions.fetchNodes).toHaveBeenCalled();
     expect(NotificationActions.notify).toHaveBeenCalledWith(
       {
         type: 'error',
-        title: 'Nodes Introspection failed',
-        message: '598612eb-f21b-435e-a868-7bb74e576cc2: Some error occurred on this node'
+        title: 'Nodes Introspection Failed',
+        message: 'Nodes Introspection failed, Some error occurred during introspection'
       }
     );
   });
@@ -245,7 +264,7 @@ describe('provideNodesFinished', () => {
   it('handles success', () => {
     const messagePayload = {
       status: 'SUCCESS',
-      message: 'Nodes were succesfully made available',
+      message: 'Nodes were successfully made available',
       execution: { input: { node_uuids: [] }}
     };
 
